@@ -121,12 +121,17 @@ def csv_to_html_table(fname,headers=None,delimiter=","):
     return table
 
 class MultiprocessDomparserResult():
-    def __init__(self, run_pool):
-        self.run_pool = run_pool
+    def __init__(self, input, inst, opts):
+        self.input = input
+        self.opts = opts
+        self.inst = inst
+
+    def _call_dom(self, opts):
+        return self.inst._exec_dom_opt(opts).html()
 
     def html(self):
-        html_outputs = self.run_pool(lambda out: out.html())
-        return html_outputs
+        pool = Pool()
+        return pool.map(self._call_dom, list(map(lambda sentence: [sentence, self.opts], self.input)))
 
 class DomparserResult():
     def __init__(self, html_content, output_pdfs, output_pngs, file_map):
@@ -478,13 +483,10 @@ class Eniam():
 
     def dom(self, input, silent=True):
         if isinstance(input, list):
-            def run_pool(mapper):
-                pool = Pool()
-                opts = {
-                    'silent': silent,
-                }
-                return pool.map(lambda opts: mapper(self._exec_dom_opt(opts)), map(lambda sentence: [sentence, opts], input))
-            return MultiprocessDomparserResult(run_pool)
+            opts = {
+                'silent': silent,
+            }
+            return MultiprocessDomparserResult(input, self, opts)
         else:
             return self._exec_dom(input, silent)
 
